Group Box Example
===============================================================================

:download:`group_box.enaml <../../../examples/containers/group_box.enaml>`

.. literalinclude:: ../../../examples/containers/group_box.enaml
    :language: python

::

 $ enaml-run group_box.enaml

.. image:: images/group_box0.png

.. image:: images/group_box1.png

.. image:: images/group_box2.png
